/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun Swiss-French type 5 keyboard.
 * By Philippe A. Kipfer (Philippe.Kipfer@di.epfl.ch), dec.1993.
 * This keyboard meet the TUV standard.
 * Defined from Sun document "Notes claviers Sun type 5" ref. #800-6803-10
 *
 */

static const KeyCode sun5swfr_codes [] = {

  /* Row 0 */
  125, 36,
  12, 13, 15, 17,
  19, 21, 23, 24,
  25, 14, 16, 18,
  29, 30, 28,
  52, 9, 11, 55,

  /* Row 1 */
  8, 10,
  49, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 50,
  51, 59, 103,
  105, 53, 54, 78,

  /* Row 2 */
  32, 33,
  60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 96,
  73, 81, 130,
  75, 76, 77, 132,

  /* Row 3 */
  56, 58,
  126, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95,
  98, 99, 100,

  /* Row 4 */
  79, 80,
  106, 131, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117,
  27,
  119, 120, 121, 97,

  /* Row 5 */
  102, 104,
  83, 26, 127, 128, 129, 74, 20,
  31, 34, 35,
  101, 57
};
